.. currentmodule:: sardana.tango.pool.Motor

:mod:`~sardana.tango.pool.Motor`
=========================================

.. automodule:: sardana.tango.pool.Motor

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Motor`
    * :class:`MotorClass`

Motor
-------

.. inheritance-diagram:: Motor
    :parts: 1
    
.. autoclass:: Motor
    :show-inheritance:
    :members:
    :undoc-members:

MotorClass
-----------

.. inheritance-diagram:: MotorClass
    :parts: 1
    
.. autoclass:: MotorClass
    :show-inheritance:
    :members:
    :undoc-members:

